/* ------------------------------------------------------------- */
/* - STBee I2C LCD module on FreeRTOS sample                     */
/*                                  released by fumi2kick        */
/*                                  http://www.fumi2kick.com/    */
/*                                  rerofumi <rero2@yuumu.org>   */
/* ------------------------------------------------------------- */
/* update                                                        */
/*   Mar.13.2011 : first release                                 */
/* ------------------------------------------------------------- */
/* memo                                                          */
/*                                                               */
/* ------------------------------------------------------------- */

/* ----------------------------------- */
/* --- include                         */
/* ----------------------------------- */

#include "stm32f10x_conf.h"

#include "freertos/FreeRTOS.h"
#include "freertos/queue.h"
#include "freertos/task.h"

#include "fm_i2c_lcd.h"

/* ----------------------------------- */
/* --- define                          */
/* ----------------------------------- */

/* ----------------------------------- */
/* --- local function prototyping      */
/* ----------------------------------- */

void vTask1(void *pcParam);

/* ----------------------------------- */
/* --- global scope                    */
/* ----------------------------------- */


/* ------------------------------------------------------------- */
/* -----  main routine                                           */
/* ------------------------------------------------------------- */

int main(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;
	
  /* --- enable to GPIO B */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);
  /* --- enable to I2C2 */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_I2C2, ENABLE);
	
  /* --- gpio port initialize */
  GPIO_InitStructure.GPIO_Pin =  0xf000;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOB, &GPIO_InitStructure);
  GPIO_ResetBits(GPIOB, 0xe000);
  /* --- I2C2 port initialize */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_10 | GPIO_Pin_11;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_OD;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOB, &GPIO_InitStructure);

  fmI2C_Init( FM_I2CLCD_I2CPORT_2 );

  /* task spown */
  xTaskCreate( vI2C_LCD_TASK, (const signed char*)"I2CLCD", 256, NULL, 1, NULL );
  xTaskCreate( vTask1, (const signed char*)"TEST", 64, NULL, 1, NULL );
  /* start scheduling, task running */
  vTaskStartScheduler();

  /* ---end working */
  while(1) {
  }
}


/* ------------------------------------------------------------- */
/* -----  local function                                         */
/* ------------------------------------------------------------- */



/* ------------------------------------------------------------- */
/* -----  task                                                   */
/* ------------------------------------------------------------- */

/* ----------------------------- */
/* --- task1                     */
/* ----------------------------- */
void vTask1(void *pcParam)
{
  uint32_t num;

  while(fmI2C_LCD_State() != STATE_I2CLCD_READY) {
    vTaskDelay(100 / portTICK_RATE_MS);
  }

  fmI2C_LCD_Contrast(180);
  fmI2C_LCD_Position(1, 0);
  fmI2C_LCD_Puts("Hello, World!", 13);

  num = 0x1234abcd;
  fmI2C_LCD_Position(0, 1);
  fmI2C_LCD_DisplayHex_8(num);
  fmI2C_LCD_Position(3, 1);
  fmI2C_LCD_DisplayHex_16(num);
  fmI2C_LCD_Position(8, 1);
  fmI2C_LCD_DisplayHex_32(num);

  vTaskSuspend(NULL);
}
